@@ -188,7 +188,25 @@ class ApiGatewayToDynamoDB(
         :summary: Constructs a new instance of the ApiGatewayToDynamoDB class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ApiGatewayToDynamoDB.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                allow_create_operation: typing.Optional[builtins.bool] = None,
+                allow_delete_operation: typing.Optional[builtins.bool] = None,
+                allow_read_operation: typing.Optional[builtins.bool] = None,
+                allow_update_operation: typing.Optional[builtins.bool] = None,
+                api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+                create_request_template: typing.Optional[builtins.str] = None,
+                delete_request_template: typing.Optional[builtins.str] = None,
+                dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
+                existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                read_request_template: typing.Optional[builtins.str] = None,
+                update_request_template: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToDynamoDBProps(
@@ -292,7 +310,23 @@ class ApiGatewayToDynamoDBProps:
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if __debug__:
-            type_hints = typing.get_type_hints(ApiGatewayToDynamoDBProps.__init__)
+            def stub(
+                *,
+                allow_create_operation: typing.Optional[builtins.bool] = None,
+                allow_delete_operation: typing.Optional[builtins.bool] = None,
+                allow_read_operation: typing.Optional[builtins.bool] = None,
+                allow_update_operation: typing.Optional[builtins.bool] = None,
+                api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+                create_request_template: typing.Optional[builtins.str] = None,
+                delete_request_template: typing.Optional[builtins.str] = None,
+                dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
+                existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                read_request_template: typing.Optional[builtins.str] = None,
+                update_request_template: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument allow_create_operation", value=allow_create_operation, expected_type=type_hints["allow_create_operation"])
             check_type(argname="argument allow_delete_operation", value=allow_delete_operation, expected_type=type_hints["allow_delete_operation"])
             check_type(argname="argument allow_read_operation", value=allow_read_operation, expected_type=type_hints["allow_read_operation"])
